"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.resolveErrorResponse = exports.didRequestFail = exports.createWebhookSecretKey = exports.processAsIntegrationHubErrorResponse = exports.handleCatchError = void 0;
const uuid_1 = require("uuid");
const error_messages_1 = require("./error-messages");
function handleCatchError(err) {
    return err instanceof Error ? err : new Error("Unknown error occurred");
}
exports.handleCatchError = handleCatchError;
function processAsIntegrationHubErrorResponse(result) {
    if (result.error) {
        return {
            success: false,
            error: new Error(`${result.error?.name} - ${result.error?.message}`),
        };
    }
    return {
        success: false,
        error: new Error("No error information was provided."),
    };
}
exports.processAsIntegrationHubErrorResponse = processAsIntegrationHubErrorResponse;
function createWebhookSecretKey() {
    return (0, uuid_1.v4)();
}
exports.createWebhookSecretKey = createWebhookSecretKey;
function didRequestFail(response) {
    return !response.success;
}
exports.didRequestFail = didRequestFail;
function resolveErrorResponse(code, error) {
    return {
        success: false,
        name: "algolia",
        code,
        reason: error_messages_1.errorMessages[code],
        error,
    };
}
exports.resolveErrorResponse = resolveErrorResponse;
