"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createIntegrationInstance = void 0;
const integration_query_1 = require("../integration-hub-queries/integration-query");
async function createIntegrationInstance(urqlClient, vars) {
    const response = await gqlCreateIntegrationInstance(urqlClient, vars);
    if (response.data && response.data.createInstance?.instance) {
        const instance = response.data.createInstance.instance;
        return {
            success: true,
            data: instance,
        };
    }
    else if (response.data?.createInstance?.errors) {
        return {
            success: false,
            error: new Error(`[errors: ${response.data?.createInstance?.errors.map((error) => `[${error.messages}]`)}`),
        };
    }
    else {
        return {
            success: false,
            error: new Error(`[${response.error?.name} - ${response.error?.message}] ${JSON.stringify(response.error)}`),
        };
    }
}
exports.createIntegrationInstance = createIntegrationInstance;
async function gqlCreateIntegrationInstance(urqlClient, vars) {
    return urqlClient.mutation(integration_query_1.CreateInstanceDocument, vars).toPromise();
}
