import { handleCatchError, processAsIntegrationHubErrorResponse, } from "../helpers";
import { GetUserInfoDocument, UserInfoFragment, } from "../integration-hub-queries/user-queries";
import { useFragment } from "../../codegen/gql";
export async function getUserInfo(urqlClient) {
    try {
        const response = await gqlGetUserInfo(urqlClient);
        const userInfoFragment = response.data &&
            useFragment(UserInfoFragment, response.data.authenticatedUser);
        if (userInfoFragment !== null && userInfoFragment !== undefined) {
            return {
                success: true,
                data: userInfoFragment,
            };
        }
        return processAsIntegrationHubErrorResponse(response);
    }
    catch (err) {
        return {
            success: false,
            error: handleCatchError(err),
        };
    }
}
async function gqlGetUserInfo(urqlClient) {
    return urqlClient.query(GetUserInfoDocument, {}).toPromise();
}
