import { z } from "zod";
import { errorCodes } from "../error-messages";
export const integrationSettingsBaseSchema = z.object({
    epccConfig: z.object({
        host: z.union([z.string(), z.literal("eu-west"), z.literal("us-east")]),
        clientId: z.string(),
        clientSecret: z.string(),
    }),
});
export const algoliaIntegrationSettingsSchema = integrationSettingsBaseSchema.merge(z.object({
    name: z.literal("algolia"),
    appId: z.string().min(1),
    adminApiKey: z.string().min(1),
}));
export const integrationCreateConfigSchema = z.discriminatedUnion("name", [
    algoliaIntegrationSettingsSchema,
]);
export const errorCodeSchema = z.enum(errorCodes);
export const integrationFailureResultBase = z.object({
    success: z.literal(false),
    code: errorCodeSchema,
    reason: z.string(),
    error: z.instanceof(Error).optional(),
});
export const algoliaIntegrationCreateSuccessResultSchema = z.object({
    success: z.literal(true),
    name: z.literal("algolia"),
    result: z.any(),
});
export const algoliaIntegrationCreateFailureResultSchema = integrationFailureResultBase.merge(z.object({
    name: z.literal("algolia"),
}));
export const algoliaIntegrationCreateResultSchema = z.discriminatedUnion("success", [
    algoliaIntegrationCreateSuccessResultSchema,
    algoliaIntegrationCreateFailureResultSchema,
]);
export const integrationCreateResultSchema = algoliaIntegrationCreateResultSchema;
