import { z } from "zod";
export declare const integrationSettingsBaseSchema: z.ZodObject<{
    epccConfig: z.ZodObject<{
        host: z.ZodUnion<[z.ZodString, z.ZodLiteral<"eu-west">, z.ZodLiteral<"us-east">]>;
        clientId: z.ZodString;
        clientSecret: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        host: string;
        clientId: string;
        clientSecret: string;
    }, {
        host: string;
        clientId: string;
        clientSecret: string;
    }>;
}, "strip", z.ZodTypeAny, {
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
}, {
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
}>;
export declare const algoliaIntegrationSettingsSchema: z.ZodObject<{
    epccConfig: z.ZodObject<{
        host: z.ZodUnion<[z.ZodString, z.ZodLiteral<"eu-west">, z.ZodLiteral<"us-east">]>;
        clientId: z.ZodString;
        clientSecret: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        host: string;
        clientId: string;
        clientSecret: string;
    }, {
        host: string;
        clientId: string;
        clientSecret: string;
    }>;
    name: z.ZodLiteral<"algolia">;
    appId: z.ZodString;
    adminApiKey: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
    appId: string;
    adminApiKey: string;
}, {
    name: "algolia";
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
    appId: string;
    adminApiKey: string;
}>;
export type AlgoliaIntegrationSettings = z.TypeOf<typeof algoliaIntegrationSettingsSchema>;
export declare const integrationCreateConfigSchema: z.ZodDiscriminatedUnion<"name", [z.ZodObject<{
    epccConfig: z.ZodObject<{
        host: z.ZodUnion<[z.ZodString, z.ZodLiteral<"eu-west">, z.ZodLiteral<"us-east">]>;
        clientId: z.ZodString;
        clientSecret: z.ZodString;
    }, "strip", z.ZodTypeAny, {
        host: string;
        clientId: string;
        clientSecret: string;
    }, {
        host: string;
        clientId: string;
        clientSecret: string;
    }>;
    name: z.ZodLiteral<"algolia">;
    appId: z.ZodString;
    adminApiKey: z.ZodString;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
    appId: string;
    adminApiKey: string;
}, {
    name: "algolia";
    epccConfig: {
        host: string;
        clientId: string;
        clientSecret: string;
    };
    appId: string;
    adminApiKey: string;
}>]>;
export type IntegrationCreateConfig = z.TypeOf<typeof integrationCreateConfigSchema>;
export declare const errorCodeSchema: z.ZodEnum<["EPCC_INTEGRATION_AUTH_TOKEN", "INTEGRATION_USER_DETAILS", "UNKNOWN", "UNKNOWN_CAUGHT_ENDPOINT", "MISSING_CUSTOMER_ID", "INTEGRATION_GET_INTEGRATION", "ALREADY_INTEGRATION_INSTANCE", "EPCC_API_KEYS", "EPCC_API_KEYS_SECRET", "CREATE_INTEGRATION_INSTANCE", "DEPLOY_INTEGRATION_INSTANCE", "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR", "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR", "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE", "CUSTOMER_JWT_DECODE"]>;
export declare const integrationFailureResultBase: z.ZodObject<{
    success: z.ZodLiteral<false>;
    code: z.ZodEnum<["EPCC_INTEGRATION_AUTH_TOKEN", "INTEGRATION_USER_DETAILS", "UNKNOWN", "UNKNOWN_CAUGHT_ENDPOINT", "MISSING_CUSTOMER_ID", "INTEGRATION_GET_INTEGRATION", "ALREADY_INTEGRATION_INSTANCE", "EPCC_API_KEYS", "EPCC_API_KEYS_SECRET", "CREATE_INTEGRATION_INSTANCE", "DEPLOY_INTEGRATION_INSTANCE", "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR", "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR", "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE", "CUSTOMER_JWT_DECODE"]>;
    reason: z.ZodString;
    error: z.ZodOptional<z.ZodType<Error, z.ZodTypeDef, Error>>;
}, "strip", z.ZodTypeAny, {
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}, {
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}>;
export declare const algoliaIntegrationCreateSuccessResultSchema: z.ZodObject<{
    success: z.ZodLiteral<true>;
    name: z.ZodLiteral<"algolia">;
    result: z.ZodAny;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    success: true;
    result?: any;
}, {
    name: "algolia";
    success: true;
    result?: any;
}>;
export declare const algoliaIntegrationCreateFailureResultSchema: z.ZodObject<{
    error: z.ZodOptional<z.ZodType<Error, z.ZodTypeDef, Error>>;
    code: z.ZodEnum<["EPCC_INTEGRATION_AUTH_TOKEN", "INTEGRATION_USER_DETAILS", "UNKNOWN", "UNKNOWN_CAUGHT_ENDPOINT", "MISSING_CUSTOMER_ID", "INTEGRATION_GET_INTEGRATION", "ALREADY_INTEGRATION_INSTANCE", "EPCC_API_KEYS", "EPCC_API_KEYS_SECRET", "CREATE_INTEGRATION_INSTANCE", "DEPLOY_INTEGRATION_INSTANCE", "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR", "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR", "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE", "CUSTOMER_JWT_DECODE"]>;
    success: z.ZodLiteral<false>;
    reason: z.ZodString;
    name: z.ZodLiteral<"algolia">;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}>;
export type AlgoliaIntegrationCreateFailureResult = z.TypeOf<typeof algoliaIntegrationCreateFailureResultSchema>;
export declare const algoliaIntegrationCreateResultSchema: z.ZodDiscriminatedUnion<"success", [z.ZodObject<{
    success: z.ZodLiteral<true>;
    name: z.ZodLiteral<"algolia">;
    result: z.ZodAny;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    success: true;
    result?: any;
}, {
    name: "algolia";
    success: true;
    result?: any;
}>, z.ZodObject<{
    error: z.ZodOptional<z.ZodType<Error, z.ZodTypeDef, Error>>;
    code: z.ZodEnum<["EPCC_INTEGRATION_AUTH_TOKEN", "INTEGRATION_USER_DETAILS", "UNKNOWN", "UNKNOWN_CAUGHT_ENDPOINT", "MISSING_CUSTOMER_ID", "INTEGRATION_GET_INTEGRATION", "ALREADY_INTEGRATION_INSTANCE", "EPCC_API_KEYS", "EPCC_API_KEYS_SECRET", "CREATE_INTEGRATION_INSTANCE", "DEPLOY_INTEGRATION_INSTANCE", "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR", "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR", "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE", "CUSTOMER_JWT_DECODE"]>;
    success: z.ZodLiteral<false>;
    reason: z.ZodString;
    name: z.ZodLiteral<"algolia">;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}>]>;
export type AlgoliaIntegrationCreateResult = z.TypeOf<typeof algoliaIntegrationCreateResultSchema>;
export declare const integrationCreateResultSchema: z.ZodDiscriminatedUnion<"success", [z.ZodObject<{
    success: z.ZodLiteral<true>;
    name: z.ZodLiteral<"algolia">;
    result: z.ZodAny;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    success: true;
    result?: any;
}, {
    name: "algolia";
    success: true;
    result?: any;
}>, z.ZodObject<{
    error: z.ZodOptional<z.ZodType<Error, z.ZodTypeDef, Error>>;
    code: z.ZodEnum<["EPCC_INTEGRATION_AUTH_TOKEN", "INTEGRATION_USER_DETAILS", "UNKNOWN", "UNKNOWN_CAUGHT_ENDPOINT", "MISSING_CUSTOMER_ID", "INTEGRATION_GET_INTEGRATION", "ALREADY_INTEGRATION_INSTANCE", "EPCC_API_KEYS", "EPCC_API_KEYS_SECRET", "CREATE_INTEGRATION_INSTANCE", "DEPLOY_INTEGRATION_INSTANCE", "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR", "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR", "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE", "CUSTOMER_JWT_DECODE"]>;
    success: z.ZodLiteral<false>;
    reason: z.ZodString;
    name: z.ZodLiteral<"algolia">;
}, "strip", z.ZodTypeAny, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}, {
    name: "algolia";
    code: "EPCC_INTEGRATION_AUTH_TOKEN" | "INTEGRATION_USER_DETAILS" | "UNKNOWN" | "UNKNOWN_CAUGHT_ENDPOINT" | "MISSING_CUSTOMER_ID" | "INTEGRATION_GET_INTEGRATION" | "ALREADY_INTEGRATION_INSTANCE" | "EPCC_API_KEYS" | "EPCC_API_KEYS_SECRET" | "CREATE_INTEGRATION_INSTANCE" | "DEPLOY_INTEGRATION_INSTANCE" | "MISSING_ALGOLIA_INTEGRATION_ID_ENV_VAR" | "MISSING_ALGOLIA_INTEGRATION_NAME_ENV_VAR" | "CUSTOMER_NOT_ALLOWED_ADD_INSTANCE" | "CUSTOMER_JWT_DECODE";
    success: false;
    reason: string;
    error?: Error | undefined;
}>]>;
export type IntegrationCreateResult = z.TypeOf<typeof integrationCreateResultSchema>;
